pub struct SyntheticSources<'a> { /* private fields */ }Implementations
Sourceimpl<'a> SyntheticSources<'a>
impl<'a> SyntheticSources<'a>
pub fn new(sources: &'a BeancountSources) -> Self
Sourceimpl<'a> SyntheticSources<'a>
impl<'a> SyntheticSources<'a>
Sourcepub fn create_synthetic_span(
&mut self,
source_name: &str,
content_fragment: &str,
) -> Span
pub fn create_synthetic_span( &mut self, source_name: &str, content_fragment: &str, ) -> Span
A synthetic span is a content fragment which doesn’t occur in the original sources, but may be referred to in error reports. Multiple fragments may share the same source name.
Sourcepub fn write_errors_or_warnings<W, E, K>(
&self,
w: &mut W,
errors_or_warnings: Vec<E>,
) -> Result<()>
pub fn write_errors_or_warnings<W, E, K>( &self, w: &mut W, errors_or_warnings: Vec<E>, ) -> Result<()>
Write human-readable error reports.
Sourcepub fn write_report<W, K, R>(&self, w: &mut W, report: &R) -> Result<()>
pub fn write_report<W, K, R>(&self, w: &mut W, report: &R) -> Result<()>
Write human-readable error or warning report.
Sourcepub fn resolve_span<'s>(&'s self, span: &Span) -> SpannedSource<'s>
pub fn resolve_span<'s>(&'s self, span: &Span) -> SpannedSource<'s>
Resolve the span into filename, line number range, and spanned content. Filename will be present unless the sources were created from an inline string.
pub fn error_source_text<'s, K>(
&'s self,
error_or_warning: &ErrorOrWarning<K>,
) -> &'s strwhere
K: ErrorOrWarningKind,