pub trait ElementType<'a> {
// Required method
fn element_type(&self) -> &'a str;
}Expand description
Implemented by any element, for access to its kind in error reporting.
pub trait ElementType<'a> {
// Required method
fn element_type(&self) -> &'a str;
}Implemented by any element, for access to its kind in error reporting.